@@ -151,3 +151,10 @@ class RealServerMissingLoadmasterInfo(MissingInfo):
 class RealServerMissingVirtualServiceInfo(MissingInfo):
     service = 'Real server'
     param_name = 'Virtual service'
+
+
+class BackupFailed(Exception):
+    def __init__(self, ip_address):
+        msg = ("Failed to create a backup. Could not reach LoadMaster {}."
+               .format(ip_address))
+        super(BackupFailed, self).__init__(msg)
