@@ -37,7 +37,7 @@ class Test_HttpClient_as_context_manager:
 class Test_HttpClient_do_request:
 
     def setup(self):
-        self.p_requests = patch.object(client, 'requests')
+        self.p_requests = patch.object(client, 'tls_session')
         requests = self.p_requests.start()
 
         self.response = MagicMock()
